/******************IO定义**************************/
char IO_JQ8X00_BusyCheck = 2;        //忙检测IO引脚
char IO_JQ8X00_VPP = 3;         //单线串口通信IO引脚

/******************全局变量**************************/
char JQ8X00_BusyCheck = 0;     //忙检测，0表示不做忙检测，1表做忙检测

typedef enum {
  Play     = 0x11,         /*播放*/
  Pause   = 0x12,         /*暂停*/
  Stop    = 0x13,         /*停止*/
  LastSong    = 0x14,         /*上一曲*/
  NextSong  = 0x15,         /*下一曲*/
  LastList  = 0x16,         /*上一目录*/
  NextList  = 0x17,         /*下一目录*/
  ChooseSD  = 0x18,         /*选择SD卡*/
  ChooseUdisk = 0x19,         /*选择U盘*/
  ChooseFlash = 0x1a,         /*选择Flash*/
  SysSleep  = 0x1b,         /*系统睡眠*/
} LineByteSelect;

typedef enum {
  Track     = 0x0B,         /*曲目*/
  Volume    = 0x0C,         /*音量*/
  EQ      = 0x0D,         /*EQ*/
  LoopMode    = 0x0E,         /*循环模式*/
  Channel   = 0x0F,         /*通道*/
  CBTrack   = 0x10,         /*插播曲目*/
} LineModeSelect;


/************************************************************************
  功能描述：  单线控制单字节发送函数
  入口参数：   DATA：发送数据
  返 回 值： none
  其他说明： 将需要发送的数据作为形参传入
**************************************************************************/
void OneLine_SendData(u8 DATA)
{
  u8 i;

  digitalWrite(IO_JQ8X00_VPP, HIGH);  //开始信号
  delayMicroseconds(100);
  digitalWrite(IO_JQ8X00_VPP, LOW);;
  delay(3);

  for (i = 0; i < 8; i++)
  {
    digitalWrite(IO_JQ8X00_VPP, HIGH);
    if (DATA & 0x01)
    {
      delayMicroseconds(1500);
      digitalWrite(IO_JQ8X00_VPP, LOW);
      delayMicroseconds(500);
    }
    else
    {
      delayMicroseconds(500);
      digitalWrite(IO_JQ8X00_VPP, LOW);
      delayMicroseconds(1500);
    }
    DATA >>= 1;
  }

  digitalWrite(IO_JQ8X00_VPP, HIGH);
}

/************************************************************************
  功能描述： 单线字节控制
  入口参数：   Mode：功能
  返 回 值： none
  其他说明： 将需要的功能作为形参传入
**************************************************************************/
void OneLine_ByteControl(LineByteSelect Mode)
{
  if (JQ8X00_BusyCheck)
  {
    delay(10);
    while (digitalRead(IO_JQ8X00_BusyCheck) == HIGH);     //忙检测
  }

  OneLine_SendData(Mode);
}

/************************************************************************x
  功能描述： 单线控制组合发送函数
  入口参数：   Nume：数字，Mode：功能
  返 回 值： none
  其他说明： 将需要发送的数据和需要的功能作为形参传入
**************************************************************************/
void OneLine_ZHControl(LineModeSelect Mode, u8 Nume)
{
  if (JQ8X00_BusyCheck)
  {
    delay(10);
    while (digitalRead(IO_JQ8X00_BusyCheck) == HIGH);     //忙检测
  }

  OneLine_SendData(0x0a);
  if (Nume < 10)
  {
    OneLine_SendData(Nume);
  }
  else
  {
    OneLine_SendData(Nume / 10);
    OneLine_SendData(Nume % 10);
  }
  OneLine_SendData(Mode);
}

void setup()
{
  if (JQ8X00_BusyCheck)
    pinMode(IO_JQ8X00_BusyCheck, INPUT);       //忙检测引脚初始化

  pinMode(IO_JQ8X00_VPP, OUTPUT);       //VPP单线串口引脚初始化
  digitalWrite(IO_JQ8X00_VPP, HIGH);    //VPP引脚拉高

  OneLine_ZHControl(Volume, 30);      //音量设置为30
  delay(10);
  OneLine_ZHControl(Track, 1);      //播放第一个音频文件

}

void loop()
{

}
