#include <string.h>
/******************IO定义**************************/
int IO_JR6001_BusyCheck = 4;        //忙检测IO

/******************全局变量**************************/
int JR6001_BusyCheck = 0;     //忙检测，0表示不做忙检测，1表做忙检测

typedef enum
{
  OverallCycle                = 0X00,         /*全盘循环 按顺序播放全盘曲目,播放完后循环播放*/
  SingleCycle                 = 0x01,         /*单曲循环 一直循环播放当前曲目*/
  SingleStop                  = 0x02,         /*单曲停止 播放完当前曲目一次停止*/
  OverallRandom               = 0X03,         /*全盘随机 随机播放盘符内曲目*/
  CatalogCycle                = 0X04,          /*目录循环 按顺序播放当前文件夹内曲目,播放完后循环播放，目录不包含子目录*/
  CatalogRandom               = 0x05,          /*目录随机 在当前目录内随机播放，目录不包含子目录*/
  CatalogTurnPlay             = 0x06,         /*目录顺序播放 按顺序播放当前文件夹内曲目,播放完后停止，目录不包含子目录*/
  OverallTurnPlay             = 0x07,         /*全盘顺序播放 按顺序播放全盘曲目,播放完后停止*/
} LoopModeSelect;     //循环模式选择

/**********************串口控制**************************/
typedef enum
{
  Play                            = 0x01,         /*播放*/
  pause                           = 0x02,         /*暂停*/
  Stop                            = 0x03,         /*停止*/
  LastSong                        = 0x04,         /*上一曲*/
  NextSong                        = 0x05,         /*下一曲*/
  EndPlay                         = 0x06,         /*结束播放*/
  AddVolume                       = 0x07,         /*音量加*/
  DecVolume                       = 0x08,         /*音量减*/
  EndZHPlay                       = 0X09,         /*结束组合播报*/
} UartCommand;    //无数据的指令

typedef enum
{
  SetVolume                       = 0x01,                 /*音量设置*/
  SetLoopMode                     = 0x02,                 /*设置循环模式*/
} UartCommandData;     //包含数据的指令,指令-数据

typedef enum
{
  JR6001_USB                      = 0X00,                 /*UPANND*/
  JR6001_SD                       = 0x01,                 /*SD*/
  JR6001_FLASH                    = 0x02,                 /*FLASH*/
} JR6001_Symbol;     //系统盘符

typedef enum
{
  PathPlay					              = 0x01,               /*路径播放*/
  InsertPlay					            = 0x02,               /*路径插播*/
} PathModeSet;					//路径播放模式设置
/******************函数定义区**************************/

/************************************************************************
  功能描述：指令类型
  入口参数：   Command：模式
  返 回 值： none
  其他说明： 不带数据的指令播放函数
**************************************************************************/
void  JR6001_Command(UartCommand Command)
{
  switch (Command)
  {
    case Play:
      Serial.print("A2");
      break;
    case pause:
      Serial.print("A3");
      break;
    case Stop:
      Serial.print("A4");
      break;
    case LastSong:
      Serial.print("A5");
      break;
    case NextSong:
      Serial.print("A6");
      break;
    case EndPlay:
      Serial.print("AE");
      break;
    case AddVolume:
      Serial.print("B0");
      break;
    case DecVolume:
      Serial.print("B1");
      break;
    case EndZHPlay:
      Serial.print("B8");
      break;
  }
  if (JR6001_BusyCheck)
  {
    delay(10);
    while (digitalRead(IO_JR6001_BusyCheck) == HIGH);     //忙检测
  }

}

/************************************************************************
  功能描述：起始码-指令类型-数据长度-数据-校验和
  入口参数：   *DAT：字符串指针,Len字符串长度
  返 回 值： none
  其他说明：
**************************************************************************/
void  JR6001_Command_Data(UartCommandData Command, u8 DATA)
{
  char Buffer[6] = {0};

  switch (Command)
  {
    case SetVolume:
      Buffer[0] = 'A';
      Buffer[1] = 'F';
      break;
    case SetLoopMode:
      Buffer[0] = 'B';
      Buffer[1] = '4';
      break;
  }
  Buffer[2] = ':';
  Buffer[3] = DATA / 10 + '0';    //将数字拆分转化为字符
  Buffer[4] = DATA % 10 + '0';
  Buffer[5] = NULL;    //字符串结束符号
  if (JR6001_BusyCheck)
  {
    delay(10);
    while (digitalRead(IO_JR6001_BusyCheck) == HIGH);     //忙检测
  }
  Serial.print(Buffer);
}

/************************************************************************
  功能描述：播放当前存储器根目录下指定文件名音频文件
  入口参数：*DATA:需要播放的文件名
  返 回 值： none
  其他说明：播放目录下文件名为00001.mp3的音频，JR6001_AppointPlay("00001");
**************************************************************************/
void JR6001_AppointPlay(char *DATA)
{
  char Buffer[20] = {0};
  Buffer[0] = 'A';
  Buffer[1] = '7';
  Buffer[2] = ':';

  strcat(Buffer, DATA);     //拼接字符串

  if (JR6001_BusyCheck)
  {
    delay(10);
    while (digitalRead(IO_JR6001_BusyCheck) == HIGH);     //忙检测
  }

  Serial.print(Buffer);
}

/************************************************************************
  功能描述：组合播报函数
  入口参数：   *DAT：组合播放的文件名
  返 回 值： none
  其他说明： ZH文件夹内的音频组合播放，文件名必须为两位数字
           将根目录下ZH文件夹需要播报的文件名作为形参即可,例：组合播放01,02文件，JR6001_ZuHeBoFang（“0102”）
**************************************************************************/
void  JR6001_ZuHeBoFang(unsigned char *DATA)
{
  char Buffer[20] = {0};

  Buffer[0] = 'B';
  Buffer[1] = '7';
  Buffer[2] = ':';

  strcat(Buffer, DATA);     //拼接字符串

  if (JR6001_BusyCheck)
  {
    delay(10);
    while (digitalRead(IO_JR6001_BusyCheck) == HIGH);     //忙检测
  }

  Serial.print(Buffer);
}

/************************************************************************
  功能描述：任意路径播放/插播函数
  入口参数：   PathModeSet:路径播放/插播，JR6001_Symbol：系统盘符，*DAT：路径
  返 回 值： none
  其他说明： 播放FLAH中MUSIC文件夹下的00005音频，例：JR6001_RandomPathPlayOrInsert(PathPlay,JR6001_FLASH,“/MUSIC* /00005*???”);
**************************************************************************/
void JR6001_RandomPathPlayOrInsert(PathModeSet Mode, JR6001_Symbol Symbol, char *DATA)
{
  char Buffer[40] = {0};
  if (Mode == PathPlay)   //路径播放
  {
    Buffer[0] = 'A';
    Buffer[1] = '8';
  }
  else
  {
    Buffer[0] = 'B';
    Buffer[1] = '3';
  }
  Buffer[2] = ':';
  Buffer[3] = '0';
  Buffer[4] = Symbol + '0';     //转字符

  strcat(Buffer, DATA);     //拼接字符串
  Serial.print(Buffer);
}


void setup()
{
  if (JR6001_BusyCheck)
    pinMode(IO_JR6001_BusyCheck, INPUT_PULLUP);                         //忙检测引脚初始化

  Serial.begin(9600);                                         //波特率9600
  delay(1000);      //等待模块上电稳定
  JR6001_Command_Data(SetVolume, 30);         //设置音量30
  delay(10);          //等待模块处理完上一条指令
  // JR6001_AppointPlay("00002");         //播放根目录下文件名为00001的音频文件,音频文件必须为5位，例：00011.mp3
  //  JR6001_ZuHeBoFang("0102");         //依次播放ZH文件夹内名为01 02的音频
  JR6001_RandomPathPlayOrInsert(PathPlay, JR6001_FLASH, "/MUSIC*/01*???");    //播放 FLASH根目录->MUSIC 下文件名为01的音频
  //  JR6001_RandomPathPlayOrInsert(PathPlay,JR6001_FLASH,"/00005*???");              //播放 FLASH根目录下文件名为00005的音频
}

void loop()
{

}
